# swallow-head

- head of [swallow computer](../swallow), without the DC motor drivers.
- width x height x length: 140 mm x 95 mm x 75 mm
- used for [swallow design](https://github.com/kamangir/bluer-ugv/tree/main/bluer_ugv/docs/swallow) backs and [rangin](https://github.com/kamangir/bluer-ugv/tree/main/bluer_ugv/docs/rangin) tops.
- [parts](./parts.md)
- previous versions: [v1](./v1.md).

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/01.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/01.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/02.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/02.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/03.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/03.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/04.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/04.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/05.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/05.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/06.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v2/06.jpg?raw=true) |
